use hmacsha::ShaTypes;

pub const DEFAULT_BREADTH: u64 = 0;
pub const DEFAULT_COUNTER: u64 = 0;
pub const DEFAULT_DIGITS: u32 = 6;
pub const DEFAULT_PERIOD: u64 = 30;
pub const DEFAULT_ALGORITHM: &ShaTypes = &ShaTypes::Sha1;
